/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.grainPriceCollect.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.grainPriceCollect.entity.GrainPriceCollect;
import com.unis.basic.info.modular.grainPriceCollect.param.GrainPriceCollectAddParam;
import com.unis.basic.info.modular.grainPriceCollect.param.GrainPriceCollectEditParam;
import com.unis.basic.info.modular.grainPriceCollect.param.GrainPriceCollectIdParam;
import com.unis.basic.info.modular.grainPriceCollect.param.GrainPriceCollectPageParam;
import com.unis.basic.info.modular.grainPriceCollect.service.GrainPriceCollectService;
import com.unis.basic.info.modular.grainPriceCollectCitySum.param.GrainPriceCollectCitySumIdParam;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Map;

/**
 * 粮食价格采集控制器
 *
 * @author TS
 * @date  2024/04/03 10:44
 */
@Api(tags = "粮食价格采集控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class GrainPriceCollectController {

    @Resource
    private GrainPriceCollectService grainPriceCollectService;

/*    *//**
     * 获取粮食价格采集分页
     *
     * @author TS
     * @date  2024/04/03 10:44
     *//*
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取粮食价格采集分页")
//    @SaCheckPermission("/basic.info/grainPriceCollect/page")
    @GetMapping("/basic.info/grainPriceCollect/page")
    public CommonResult<Page<GrainPriceCollect>> page(GrainPriceCollectPageParam grainPriceCollectPageParam) {
        return CommonResult.data(grainPriceCollectService.page(grainPriceCollectPageParam));
    }*/
    /**
     * 获取自定义粮食价格采集分页
     *
     * @author TS
     * @date  2024/04/08 14:44
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取自定义粮食价格采集分页")
//    @SaCheckPermission("/basic.info/grainPriceCollect/findPage")
    @GetMapping("/basic.info/grainPriceCollect/findPage")
    public CommonResult<IPage<Map<String,Object>>> findPage(GrainPriceCollectPageParam grainPriceCollectPageParam) {
        return CommonResult.data(grainPriceCollectService.findPage(grainPriceCollectPageParam));
    }

    /**
     * 添加粮食价格采集
     *
     * @author ZeroLiYi
     * @date  2024/04/03 10:44
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("APP添加粮食价格采集")
    @CommonLog("APP添加粮食价格采集")
//    @SaCheckPermission("/basic.info/grainPriceCollect/add")
    @PostMapping("/client/c/grainPriceCollect/add")
    public CommonResult<String> add(@RequestBody @Valid GrainPriceCollectAddParam grainPriceCollectAddParam) {
        grainPriceCollectService.add(grainPriceCollectAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑粮食价格采集
     *
     * @author TS
     * @date  2024/04/03 10:44
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑粮食价格采集")
    @CommonLog("编辑粮食价格采集")
//    @SaCheckPermission("/basic.info/grainPriceCollect/edit")
    @PostMapping("/basic.info/grainPriceCollect/edit")
    public CommonResult<String> edit(@RequestBody @Valid GrainPriceCollectEditParam grainPriceCollectEditParam) {
        grainPriceCollectService.edit(grainPriceCollectEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除粮食价格采集
     *
     * @author TS
     * @date  2024/04/03 10:44
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除粮食价格采集")
    @CommonLog("删除粮食价格采集")
//    @SaCheckPermission("/basic.info/grainPriceCollect/delete")
    @PostMapping("/basic.info/grainPriceCollect/delete")
    public CommonResult<String> delete(@RequestBody @Valid  GrainPriceCollectIdParam grainPriceCollectIdParam) {
        grainPriceCollectService.delete(grainPriceCollectIdParam);
        return CommonResult.ok();
    }

    /**
     * 获取粮食价格采集详情
     *
     * @author TS
     * @date  2024/04/03 10:44
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取粮食价格采集详情")
//    @SaCheckPermission("/basic.info/grainPriceCollect/detail")
    @GetMapping("/basic.info/grainPriceCollect/detail")
    public CommonResult<GrainPriceCollect> detail(@Valid GrainPriceCollectIdParam grainPriceCollectIdParam) {
        return CommonResult.data(grainPriceCollectService.detail(grainPriceCollectIdParam));
    }
    /**
     * 获取当前用户所有粮监测点信息
     *
     * @author TS
     * @date  2024/04/03 10:44
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取当前用户所有粮监测点信息")
  //  @SaCheckPermission("/basic.info/grainPriceCollect/getMonitorInfo")
    @GetMapping("/client/c/grainPriceCollect/getMonitorInfo")
    public CommonResult<List<Map<String, Object>>> getMonitorInfo() {
        return CommonResult.data(grainPriceCollectService.getMonitorInfo());
    }
    /**
     * 获取当前用户最近粮监测点信息
     *
     * @author TS
     * @date  2024/04/03 10:44
     */
    @ApiOperationSupport(order = 7)
    @ApiOperation("APP获取当前用户最近粮监测点信息")
  //  @SaCheckPermission("/basic.info/grainPriceCollect/getMonitorInfoByPoint")
    @GetMapping("/client/c/grainPriceCollect/getMonitorInfoByPoint")
    public CommonResult<Map<String, Object>> getMonitorInfoByPoint(@RequestParam(value = "point") @NotEmpty(message = "坐标不能为空，例如:POINT(1 2)") String point) {
        return CommonResult.data(grainPriceCollectService.getMonitorInfoByPoint(point));
    }

    /**
     * 审核粮食价格采集
     *
     * @author TS
     * @date  2024/04/9 19:44
     */
    @ApiOperationSupport(order = 8)
    @ApiOperation("审核粮食价格采集")
    @CommonLog("审核粮食价格采集")
    // @SaCheckPermission("/basic.info/grainPriceCollect/audit")
    @GetMapping("/basic.info/grainPriceCollect/audit")
    public CommonResult<String> audit(@Valid GrainPriceCollectIdParam grainPriceCollectIdParam) {
        return CommonResult.data(grainPriceCollectService.audit(grainPriceCollectIdParam));
    }

    /**
     * 获取自定义粮食价格采集分页
     *
     * @author ZeroLiYi
     * @date  2024/04/08 14:44
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("APP粮食价格采集分页")
//    @SaCheckPermission("/basic.info/grainPriceCollect/findAppPage")
    @GetMapping("/client/c/grainPriceCollect/findAppPage")
    public CommonResult<IPage<Map<String,Object>>> findAppPage(GrainPriceCollectPageParam grainPriceCollectPageParam) {
        return CommonResult.data(grainPriceCollectService.findPage(grainPriceCollectPageParam));
    }
    /**
     * APP获取粮食价格采集详情
     *
     * @author ZeroLiYi
     * @date
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("APP获取粮食价格采集详情")
//    @SaCheckPermission("/basic.info/grainPriceCollect/detail")
    @GetMapping("/client/c/grainPriceCollect/APPdetail")
    public CommonResult<GrainPriceCollect> APPdetail(@Valid GrainPriceCollectIdParam grainPriceCollectIdParam) {
        return CommonResult.data(grainPriceCollectService.detail(grainPriceCollectIdParam));
    }
    

}
