/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.grainPriceCollectCategory.param;

import io.swagger.annotations.ApiModelProperty;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 粮食价格采集-品种编辑参数
 *
 * @author TS
 * @date  2024/04/03 10:41
 **/
@Getter
@Setter
public class GrainPriceCollectCategoryEditParam {

    /** ID */
    @ApiModelProperty(value = "ID", required = true, position = 1)
    @NotBlank(message = "id不能为空")
    private String id;

    /** 类型 1：粮食价格采集；2：市级粮食价格采集汇总；3：省级粮食价格采集汇总； */
    @ApiModelProperty(value = "类型 1：粮食价格采集；2：市级粮食价格采集汇总；3：省级粮食价格采集汇总；", position = 7)
    private Integer type;

    /** type=1，biz_grain_price_collect的id；
type=2，biz_grain_price_collect_city_sum的id;
type=3，biz_grain_price_collect_province_sum的id； */
    @ApiModelProperty(value = "type=1，biz_grain_price_collect的id；type=2，biz_grain_price_collect_city_sum的id;type=3，biz_grain_price_collect_province_sum的id；", position = 8)
    private String typeId;

    /** 一级分类 1：原粮；2：杂粮；3：成品粮；4：省级储备； */
    @ApiModelProperty(value = "一级分类 1：原粮；2：杂粮；3：成品粮；4：省级储备；", position = 9)
    private Integer firstLevel;

    /** 二级分类   
11：小麦；12：青稞；13：油菜籽；
21：黄豆；22：玉米面；23：小米；
31：菜籽油；32：面粉；33：粳米；
41：省级储备小麦；42：省级储备青稞；43：省级储备菜籽油； */
    @ApiModelProperty(value = "二级分类   11：小麦；12：青稞；13：油菜籽；21：黄豆；22：玉米面；23：小米；31：菜籽油；32：面粉；33：粳米；41：省级储备小麦；42：省级储备青稞；43：省级储备菜籽油；", position = 10)
    private Integer secondLevel;

    /** 三级分类  
311：一级菜籽油；312：三级菜籽油；313：小榨菜籽油；
321：特一粉；322：牛肉面粉；
331：一级长粒粳米；332：一级圆粒粳米； */
    @ApiModelProperty(value = "三级分类  311：一级菜籽油；312：三级菜籽油；313：小榨菜籽油；321：特一粉；322：牛肉面粉；331：一级长粒粳米；332：一级圆粒粳米；", position = 11)
    private Integer threeLevel;

    /** 价格类型 1：收购价；2：入库价；3：出库价；4：出厂价；5：批发价；6：零售价； */
    @ApiModelProperty(value = "价格类型 1：收购价；2：入库价；3：出库价；4：出厂价；5：批发价；6：零售价；", position = 12)
    private Integer priceType;

    /** 价格（或平均价格） */
    @ApiModelProperty(value = "价格（或平均价格）", position = 13)
    private BigDecimal price;

    /** 与上周同期比。不可大于1。type=3是有值； */
    @ApiModelProperty(value = "与上周同期比。不可大于1。type=3是有值；", position = 14)
    private BigDecimal weekRate;

    /** 与上月同期比。不可大于1。type=3是有值； */
    @ApiModelProperty(value = "与上月同期比。不可大于1。type=3是有值；", position = 15)
    private BigDecimal monthRate;

    /** 与去年同期比。不可大于1。type=3是有值； */
    @ApiModelProperty(value = "与去年同期比。不可大于1。type=3是有值；", position = 16)
    private BigDecimal yearRate;

}
