/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.pricemonitor.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.pricemonitor.param.PriceMonitorAddParam;
import com.unis.basic.info.modular.pricemonitor.vo.PriceMonitorVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.basic.info.modular.pricemonitor.entity.PriceMonitor;
import com.unis.basic.info.modular.pricemonitor.param.PriceMonitorAddParam;
import com.unis.basic.info.modular.pricemonitor.param.PriceMonitorEditParam;
import com.unis.basic.info.modular.pricemonitor.param.PriceMonitorIdParam;
import com.unis.basic.info.modular.pricemonitor.param.PriceMonitorPageParam;
import com.unis.basic.info.modular.pricemonitor.service.PriceMonitorService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 价格监测控制器
 *
 * @author weiyinbin
 * @date  2024/04/02 15:09
 */
@Api(tags = "价格监测控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class PriceMonitorController {

    @Resource
    private PriceMonitorService priceMonitorService;

    /**
     * 获取价格监测分页
     *
     * @author weiyinbin
     * @date  2024/04/02 15:09
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取价格监测分页")
    //@SaCheckPermission("/basic.info/pricemonitor/page")
    @GetMapping("/basic.info/pricemonitor/page")
    public CommonResult<IPage<PriceMonitorVO>> page(PriceMonitorPageParam priceMonitorPageParam) {
        return CommonResult.data(priceMonitorService.page(priceMonitorPageParam));
    }

    /**
     * 添加价格监测
     *
     * @author weiyinbin
     * @date  2024/04/02 15:09
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加价格监测")
    @CommonLog("添加价格监测")
    //@SaCheckPermission("/basic.info/pricemonitor/add")
    @PostMapping("/basic.info/pricemonitor/add")
    public CommonResult<String> add(@RequestBody @Valid PriceMonitorAddParam priceMonitorAddParam) {
        return priceMonitorService.add(priceMonitorAddParam);
    }

    /**
     * 编辑价格监测
     *
     * @author weiyinbin
     * @date  2024/04/02 15:09
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑价格监测")
    @CommonLog("编辑价格监测")
   // @SaCheckPermission("/basic.info/pricemonitor/edit")
    @PostMapping("/basic.info/pricemonitor/edit")
    public CommonResult<String> edit(@RequestBody @Valid PriceMonitorEditParam priceMonitorEditParam) {
        priceMonitorService.edit(priceMonitorEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除价格监测
     *
     * @author weiyinbin
     * @date  2024/04/02 15:09
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除价格监测")
    @CommonLog("删除价格监测")
   // @SaCheckPermission("/basic.info/pricemonitor/delete")
    @PostMapping("/basic.info/pricemonitor/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PriceMonitorIdParam> priceMonitorIdParamList) {
        priceMonitorService.delete(priceMonitorIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取价格监测详情
     *
     * @author weiyinbin
     * @date  2024/04/02 15:09
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取价格监测详情")
   // @SaCheckPermission("/basic.info/pricemonitor/detail")
    @GetMapping("/basic.info/pricemonitor/detail")
    public CommonResult<PriceMonitor> detail(@Valid PriceMonitorIdParam priceMonitorIdParam) {
        return CommonResult.data(priceMonitorService.detail(priceMonitorIdParam));
    }
}
