/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.reportpricemonitor.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.pricemonitor.mapper.PriceMonitorMapper;
import com.unis.basic.info.modular.unReporCity.entity.UnReporCity;
import com.unis.basic.info.modular.unReporCity.mapper.UnReporCityMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.basic.info.modular.reportpricemonitor.entity.ReportPriceMonitor;
import com.unis.basic.info.modular.reportpricemonitor.mapper.ReportPriceMonitorMapper;
import com.unis.basic.info.modular.reportpricemonitor.param.ReportPriceMonitorAddParam;
import com.unis.basic.info.modular.reportpricemonitor.param.ReportPriceMonitorEditParam;
import com.unis.basic.info.modular.reportpricemonitor.param.ReportPriceMonitorIdParam;
import com.unis.basic.info.modular.reportpricemonitor.param.ReportPriceMonitorPageParam;
import com.unis.basic.info.modular.reportpricemonitor.service.ReportPriceMonitorService;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * 漏报统计站点Service接口实现类
 *
 * @author shine
 * @date  2024/04/08 20:24
 **/
@Service
public class ReportPriceMonitorServiceImpl extends ServiceImpl<ReportPriceMonitorMapper, ReportPriceMonitor> implements ReportPriceMonitorService {

    @Resource
    private PriceMonitorMapper priceMonitorMapper;

    @Override
    public Page<ReportPriceMonitor> page(ReportPriceMonitorPageParam reportPriceMonitorPageParam) {
        QueryWrapper<ReportPriceMonitor> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(reportPriceMonitorPageParam.getUnReportCityId())) {
            queryWrapper.lambda().eq(ReportPriceMonitor::getUnReportCityId, reportPriceMonitorPageParam.getUnReportCityId());
        }
        if(ObjectUtil.isNotEmpty(reportPriceMonitorPageParam.getPriceMonitorId())) {
            queryWrapper.lambda().eq(ReportPriceMonitor::getPriceMonitorId, reportPriceMonitorPageParam.getPriceMonitorId());
        }
        if(ObjectUtil.isNotEmpty(reportPriceMonitorPageParam.getStartReportDate()) && ObjectUtil.isNotEmpty(reportPriceMonitorPageParam.getEndReportDate())) {
            queryWrapper.lambda().between(ReportPriceMonitor::getReportDate, reportPriceMonitorPageParam.getStartReportDate(), reportPriceMonitorPageParam.getEndReportDate());
        }
        if(ObjectUtil.isAllNotEmpty(reportPriceMonitorPageParam.getSortField(), reportPriceMonitorPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(reportPriceMonitorPageParam.getSortOrder());
            queryWrapper.orderBy(true, reportPriceMonitorPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(reportPriceMonitorPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(ReportPriceMonitor::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(ReportPriceMonitorAddParam reportPriceMonitorAddParam) {
        ReportPriceMonitor reportPriceMonitor = BeanUtil.toBean(reportPriceMonitorAddParam, ReportPriceMonitor.class);
        this.save(reportPriceMonitor);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(ReportPriceMonitorEditParam reportPriceMonitorEditParam) {
        ReportPriceMonitor reportPriceMonitor = this.queryEntity(reportPriceMonitorEditParam.getId().toString());
        BeanUtil.copyProperties(reportPriceMonitorEditParam, reportPriceMonitor);
        this.updateById(reportPriceMonitor);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<ReportPriceMonitorIdParam> reportPriceMonitorIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(reportPriceMonitorIdParamList, ReportPriceMonitorIdParam::getId));
    }

    @Override
    public ReportPriceMonitor detail(ReportPriceMonitorIdParam reportPriceMonitorIdParam) {
        return this.queryEntity(reportPriceMonitorIdParam.getId().toString());
    }

    @Override
    public ReportPriceMonitor queryEntity(String id) {
        ReportPriceMonitor reportPriceMonitor = this.getById(id);
        if(ObjectUtil.isEmpty(reportPriceMonitor)) {
            throw new CommonException("漏报统计站点不存在，id值为：{}", id);
        }
        return reportPriceMonitor;
    }

    @Override
    public List<Map<String, Object>> exportByEntityResult(ReportPriceMonitor reportPriceMonitor,String sysOrgName) {
        {
            QueryWrapper<ReportPriceMonitor> queryWrapper = new QueryWrapper<>();
            if(reportPriceMonitor.getUnReportCityId()!=null){
                queryWrapper.eq("un_report_city_id",reportPriceMonitor.getUnReportCityId());
            }
            if(reportPriceMonitor.getPriceMonitorId()!= null){
                queryWrapper.eq("price_monitor_id",reportPriceMonitor.getPriceMonitorId());
            }
            List<Map<String, Object>> data = this.listMaps(queryWrapper);
            int  number = 0;
            for (Map<String, Object> map : data) {
                number++;
                map.put("sysOrgName",sysOrgName);
                map.put("number",number);
                String siteName =  priceMonitorMapper.selectById(reportPriceMonitor.getPriceMonitorId()).getName();
                map.put("siteName",siteName);
            }
            return data;
        }
    }
}
