/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.unReporCity.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.basic.info.modular.remindcycle.entity.RemindCycle;
import com.unis.basic.info.modular.remindcycle.mapper.RemindCycleMapper;
import com.unis.basic.info.modular.reportpricemonitor.entity.ReportPriceMonitor;
import com.unis.basic.info.modular.unReporCity.entity.UnReporCity;
import com.unis.basic.info.modular.unReporCity.mapper.UnReporCityMapper;
import com.unis.basic.info.modular.unReporCity.param.UnReporCityAddParam;
import com.unis.basic.info.modular.unReporCity.param.UnReporCityEditParam;
import com.unis.basic.info.modular.unReporCity.param.UnReporCityIdParam;
import com.unis.basic.info.modular.unReporCity.param.UnReporCityPageParam;
import com.unis.basic.info.modular.unReporCity.service.UnReporCityService;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.sys.modular.org.mapper.SysOrgMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;


import java.util.List;
import java.util.Map;

/**
 * 漏报统计市州Service接口实现类
 *
 * @author weiyinbin
 * @date 2024/04/02 20:13
 **/
@Service
public class UnReporCityServiceImpl extends ServiceImpl<UnReporCityMapper, UnReporCity> implements UnReporCityService {

    /*@Autowired
    private RemindCycleMapper remindCycleMapper;*/

    @Autowired
    private UnReporCityMapper unReporCityMapper;

    @Autowired
    private SysOrgMapper sysOrgMapper;



    @Override
    public Page<UnReporCity> page(UnReporCityPageParam unReporCityPageParam) {
        QueryWrapper<UnReporCity> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(unReporCityPageParam.getSysOrgId())) {
            queryWrapper.lambda().eq(UnReporCity::getSysOrgId, unReporCityPageParam.getSysOrgId());
        }
        if (ObjectUtil.isAllNotEmpty(unReporCityPageParam.getSortField(), unReporCityPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(unReporCityPageParam.getSortOrder());
            queryWrapper.orderBy(true, unReporCityPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(unReporCityPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(UnReporCity::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(UnReporCityAddParam unReporCityAddParam) {
        UnReporCity unReporCity = BeanUtil.toBean(unReporCityAddParam, UnReporCity.class);
        this.save(unReporCity);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(UnReporCityEditParam unReporCityEditParam) {
        UnReporCity unReporCity = this.queryEntity(unReporCityEditParam.getId());
        BeanUtil.copyProperties(unReporCityEditParam, unReporCity);
        this.updateById(unReporCity);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<UnReporCityIdParam> unReporCityIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(unReporCityIdParamList, UnReporCityIdParam::getId));
    }

    @Override
    public UnReporCity detail(UnReporCityIdParam unReporCityIdParam) {
        return this.queryEntity(unReporCityIdParam.getId());
    }

    @Override
    public UnReporCity queryEntity(String id) {
        UnReporCity unReporCity = this.getById(id);
        if (ObjectUtil.isEmpty(unReporCity)) {
            throw new CommonException("漏报统计市州不存在，id值为：{}", id);
        }
        return unReporCity;
    }

    @Override
    public List<Map<String, Object>> exportByEntityResult(UnReporCity unReporCity) {
        QueryWrapper<UnReporCity> queryWrapper = new QueryWrapper<>();
        if(unReporCity.getSysOrgId()!=null && unReporCity.getSysOrgId() != ""){
            queryWrapper.eq("sys_org_id",unReporCity.getSysOrgId());
        }
        if(unReporCity.getCreateTime()!= null){
            queryWrapper.gt("create_time",unReporCity.getCreateTime());
        }
        List<Map<String, Object>> data = unReporCityMapper.selectMaps(queryWrapper);
        int  number = 0;
        for (Map<String, Object> map : data) {
            number++;
            String orgName = sysOrgMapper.selectById(map.get("sys_org_id").toString()).getName();
            map.put("sys_org_name",orgName);
            map.put("number",number);
        }
        return data;
    }

}
