/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.basic.info.modular.unitInfo.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.basic.info.modular.unitInfo.entity.BasicEnum;
import com.unis.basic.info.modular.unitInfo.param.*;
import com.unis.basic.info.modular.unitInfo.vo.BasicEnumVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.MediaType;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.basic.info.modular.unitInfo.entity.UnitInfo;
import com.unis.basic.info.modular.unitInfo.service.UnitInfoService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 单位信息表控制器
 *
 * @author hujinachun
 * @date 2024/04/16 09:08
 */
@Api(tags = "单位信息表控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class UnitInfoController {

    @Resource
    private UnitInfoService unitInfoService;

    /**
     * 获取单位信息表分页
     *
     * @author hujinachun
     * @date 2024/04/16 09:08
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取单位信息表分页")
    // @SaCheckPermission("/basic.info/unitInfo/page")
    @GetMapping("/basic.info/unitInfo/page")
    public CommonResult<Page<UnitInfo>> page(UnitInfoPageParam unitInfoPageParam) {
        return CommonResult.data(unitInfoService.page(unitInfoPageParam));
    }

    /**
     * 添加单位信息表
     *
     * @author hujinachun
     * @date 2024/04/16 09:08
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加单位信息表")
    @CommonLog("添加单位信息表")
    // @SaCheckPermission("/basic.info/unitInfo/add")
    @PostMapping("/basic.info/unitInfo/add")
    public CommonResult<String> add(@RequestBody @Valid UnitInfoAddParam unitInfoAddParam) {
        unitInfoService.add(unitInfoAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑单位信息表
     *
     * @author hujinachun
     * @date 2024/04/16 09:08
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑单位信息表")
    @CommonLog("编辑单位信息表")
    // @SaCheckPermission("/basic.info/unitInfo/edit")
    @PostMapping("/basic.info/unitInfo/edit")
    public CommonResult<String> edit(@RequestBody @Valid UnitInfoEditParam unitInfoEditParam) {
        unitInfoService.edit(unitInfoEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除单位信息表
     *
     * @author hujinachun
     * @date 2024/04/16 09:08
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除单位信息表")
    @CommonLog("删除单位信息表")
    // @SaCheckPermission("/basic.info/unitInfo/delete")
    @PostMapping("/basic.info/unitInfo/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                       CommonValidList<UnitInfoIdParam> unitInfoIdParamList) {
        unitInfoService.delete(unitInfoIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取单位信息表详情
     *
     * @author hujinachun
     * @date 2024/04/16 09:08
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取单位信息表详情")
    // @SaCheckPermission("/basic.info/unitInfo/detail")
    @GetMapping("/basic.info/unitInfo/detail")
    public CommonResult<UnitInfo> detail(@Valid UnitInfoIdParam unitInfoIdParam) {
        return CommonResult.data(unitInfoService.detail(unitInfoIdParam));
    }


    /**
     * 根据id获取所有节点,及是否包含子节点
     *
     * @param
     * @return
     */
    @GetMapping(value = "/basic.info/unitInfo/getAllChildren")
    @ApiOperation(value = "根据id获取所有节点,及是否包含子节点", notes = "根据id获取所有节点,及是否包含子节点")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "字典id", paramType = "query"),
            @ApiImplicitParam(name = "isQueryFristNode", value = "是否只查询第一级", paramType = "query")
    })
    public CommonResult<List<BasicEnumVo>> getAllChildren(@Valid UnitInfoAllChildrenParam param) {
        List<BasicEnumVo> list = unitInfoService.queryAllChildren(param.getId(),param.getIsQueryFristNode());
        return CommonResult.data(list);
    }




}
