/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.examine.modular.neassessmentScoreSum.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.examine.modular.neassessmentScoreSum.entity.BizNeAssessmentScoreSum;
import com.unis.examine.modular.neassessmentScoreSum.param.BizNeAssessmentScoreSumAddParam;
import com.unis.examine.modular.neassessmentScoreSum.param.BizNeAssessmentScoreSumEditParam;
import com.unis.examine.modular.neassessmentScoreSum.param.BizNeAssessmentScoreSumIdParam;
import com.unis.examine.modular.neassessmentScoreSum.param.BizNeAssessmentScoreSumPageParam;
import com.unis.examine.modular.neassessmentScoreSum.service.BizNeAssessmentScoreSumService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 粮食安全责任制考核-考核结果控制器
 *
 * @author ZeroLiYi
 * @date  2024/04/23 10:19
 */
@Api(tags = "粮食安全责任制考核-考核结果控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class BizNeAssessmentScoreSumController {

    @Resource
    private BizNeAssessmentScoreSumService bizNeAssessmentScoreSumService;

    /**
     * 获取粮食安全责任制考核-考核结果分页
     *
     * @author ZeroLiYi
     * @date  2024/04/23 10:19
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取粮食安全责任制考核-考核结果分页")
    @SaCheckPermission("/biz/neassessmentScoreSum/page")
    @GetMapping("/biz/neassessmentScoreSum/page")
    public CommonResult<Page<BizNeAssessmentScoreSum>> page(BizNeAssessmentScoreSumPageParam bizNeAssessmentScoreSumPageParam) {
        return CommonResult.data(bizNeAssessmentScoreSumService.page(bizNeAssessmentScoreSumPageParam));
    }

    /**
     * 添加粮食安全责任制考核-考核结果
     *
     * @author ZeroLiYi
     * @date  2024/04/23 10:19
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加粮食安全责任制考核-考核结果")
    @CommonLog("添加粮食安全责任制考核-考核结果")
    @SaCheckPermission("/biz/neassessmentScoreSum/add")
    @PostMapping("/biz/neassessmentScoreSum/add")
    public CommonResult<String> add(@RequestBody @Valid BizNeAssessmentScoreSumAddParam bizNeAssessmentScoreSumAddParam) {
        bizNeAssessmentScoreSumService.add(bizNeAssessmentScoreSumAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑粮食安全责任制考核-考核结果
     *
     * @author ZeroLiYi
     * @date  2024/04/23 10:19
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑粮食安全责任制考核-考核结果")
    @CommonLog("编辑粮食安全责任制考核-考核结果")
    @SaCheckPermission("/biz/neassessmentScoreSum/edit")
    @PostMapping("/biz/neassessmentScoreSum/edit")
    public CommonResult<String> edit(@RequestBody @Valid BizNeAssessmentScoreSumEditParam bizNeAssessmentScoreSumEditParam) {
        bizNeAssessmentScoreSumService.edit(bizNeAssessmentScoreSumEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除粮食安全责任制考核-考核结果
     *
     * @author ZeroLiYi
     * @date  2024/04/23 10:19
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除粮食安全责任制考核-考核结果")
    @CommonLog("删除粮食安全责任制考核-考核结果")
    @SaCheckPermission("/biz/neassessmentScoreSum/delete")
    @PostMapping("/biz/neassessmentScoreSum/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<BizNeAssessmentScoreSumIdParam> bizNeAssessmentScoreSumIdParamList) {
        bizNeAssessmentScoreSumService.delete(bizNeAssessmentScoreSumIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取粮食安全责任制考核-考核结果详情
     *
     * @author ZeroLiYi
     * @date  2024/04/23 10:19
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取粮食安全责任制考核-考核结果详情")
    @SaCheckPermission("/biz/neassessmentScoreSum/detail")
    @GetMapping("/biz/neassessmentScoreSum/detail")
    public CommonResult<BizNeAssessmentScoreSum> detail(@Valid BizNeAssessmentScoreSumIdParam bizNeAssessmentScoreSumIdParam) {
        return CommonResult.data(bizNeAssessmentScoreSumService.detail(bizNeAssessmentScoreSumIdParam));
    }
}
