/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.examine.modular.neassessmentScoreSum.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.examine.modular.neassessmentScoreSum.entity.BizNeAssessmentScoreSum;
import com.unis.examine.modular.neassessmentScoreSum.mapper.BizNeAssessmentScoreSumMapper;
import com.unis.examine.modular.neassessmentScoreSum.param.BizNeAssessmentScoreSumAddParam;
import com.unis.examine.modular.neassessmentScoreSum.param.BizNeAssessmentScoreSumEditParam;
import com.unis.examine.modular.neassessmentScoreSum.param.BizNeAssessmentScoreSumIdParam;
import com.unis.examine.modular.neassessmentScoreSum.param.BizNeAssessmentScoreSumPageParam;
import com.unis.examine.modular.neassessmentScoreSum.service.BizNeAssessmentScoreSumService;

import java.util.List;

/**
 * 粮食安全责任制考核-考核结果Service接口实现类
 *
 * @author ZeroLiYi
 * @date  2024/04/23 10:19
 **/
@Service
public class BizNeAssessmentScoreSumServiceImpl extends ServiceImpl<BizNeAssessmentScoreSumMapper, BizNeAssessmentScoreSum> implements BizNeAssessmentScoreSumService {

    @Override
    public Page<BizNeAssessmentScoreSum> page(BizNeAssessmentScoreSumPageParam bizNeAssessmentScoreSumPageParam) {
        QueryWrapper<BizNeAssessmentScoreSum> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(bizNeAssessmentScoreSumPageParam.getSortField(), bizNeAssessmentScoreSumPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(bizNeAssessmentScoreSumPageParam.getSortOrder());
            queryWrapper.orderBy(true, bizNeAssessmentScoreSumPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(bizNeAssessmentScoreSumPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(BizNeAssessmentScoreSum::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(BizNeAssessmentScoreSumAddParam bizNeAssessmentScoreSumAddParam) {
        BizNeAssessmentScoreSum bizNeAssessmentScoreSum = BeanUtil.toBean(bizNeAssessmentScoreSumAddParam, BizNeAssessmentScoreSum.class);
        this.save(bizNeAssessmentScoreSum);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(BizNeAssessmentScoreSumEditParam bizNeAssessmentScoreSumEditParam) {
        BizNeAssessmentScoreSum bizNeAssessmentScoreSum = this.queryEntity(bizNeAssessmentScoreSumEditParam.getId());
        BeanUtil.copyProperties(bizNeAssessmentScoreSumEditParam, bizNeAssessmentScoreSum);
        this.updateById(bizNeAssessmentScoreSum);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<BizNeAssessmentScoreSumIdParam> bizNeAssessmentScoreSumIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(bizNeAssessmentScoreSumIdParamList, BizNeAssessmentScoreSumIdParam::getId));
    }

    @Override
    public BizNeAssessmentScoreSum detail(BizNeAssessmentScoreSumIdParam bizNeAssessmentScoreSumIdParam) {
        return this.queryEntity(bizNeAssessmentScoreSumIdParam.getId());
    }

    @Override
    public BizNeAssessmentScoreSum queryEntity(String id) {
        BizNeAssessmentScoreSum bizNeAssessmentScoreSum = this.getById(id);
        if(ObjectUtil.isEmpty(bizNeAssessmentScoreSum)) {
            throw new CommonException("粮食安全责任制考核-考核结果不存在，id值为：{}", id);
        }
        return bizNeAssessmentScoreSum;
    }
}
