/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpAdviceCollect.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.policy.info.modular.mlpAdviceCollect.vo.MlpAdviceCollectVO;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.entity.MlpAdviceCollectOrgFeedback;
import com.unis.policy.info.modular.mlpAdviceCollectFeedback.param.MlpAdviceCollectOrgFeedbackAddParam;
import com.unis.policy.info.modular.mlpFirstDraftCollectFeedback.param.MlpFirstDraftCollectFeedbackAddParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.policy.info.modular.mlpAdviceCollect.entity.MlpAdviceCollect;
import com.unis.policy.info.modular.mlpAdviceCollect.param.MlpAdviceCollectAddParam;
import com.unis.policy.info.modular.mlpAdviceCollect.param.MlpAdviceCollectEditParam;
import com.unis.policy.info.modular.mlpAdviceCollect.param.MlpAdviceCollectIdParam;
import com.unis.policy.info.modular.mlpAdviceCollect.param.MlpAdviceCollectPageParam;
import com.unis.policy.info.modular.mlpAdviceCollect.service.MlpAdviceCollectService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 中长期规划管理-规划编制（意见收集）控制器
 *
 * @author hujinachun
 * @date  2024/04/18 18:02
 */
@Api(tags = "中长期规划管理-规划编制（意见收集）控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class MlpAdviceCollectController {

    @Resource
    private MlpAdviceCollectService mlpAdviceCollectService;

    /**
     * 获取中长期规划管理-规划编制（意见收集）分页
     *
     * @author hujinachun
     * @date  2024/04/18 18:02
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取中长期规划管理-规划编制（意见收集）分页")
   // @SaCheckPermission("/policy.info/mlpAdviceCollect/page")
    @GetMapping("/policy.info/mlpAdviceCollect/page")
    public CommonResult<Page<MlpAdviceCollect>> page(MlpAdviceCollectPageParam mlpAdviceCollectPageParam) {
        return CommonResult.data(mlpAdviceCollectService.page(mlpAdviceCollectPageParam));
    }

    /**
     * 添加中长期规划管理-规划编制（意见收集）
     *
     * @author hujinachun
     * @date  2024/04/18 18:02
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加中长期规划管理-规划编制（意见收集）")
    @CommonLog("添加中长期规划管理-规划编制（意见收集）")
   // @SaCheckPermission("/policy.info/mlpAdviceCollect/add")
    @PostMapping("/policy.info/mlpAdviceCollect/add")
    public CommonResult<String> add(@RequestBody @Valid MlpAdviceCollectAddParam mlpAdviceCollectAddParam) {
        mlpAdviceCollectService.add(mlpAdviceCollectAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑中长期规划管理-规划编制（意见收集）
     *
     * @author hujinachun
     * @date  2024/04/18 18:02
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑中长期规划管理-规划编制（意见收集）")
    @CommonLog("编辑中长期规划管理-规划编制（意见收集）")
   // @SaCheckPermission("/policy.info/mlpAdviceCollect/edit")
    @PostMapping("/policy.info/mlpAdviceCollect/edit")
    public CommonResult<String> edit(@RequestBody @Valid MlpAdviceCollectEditParam mlpAdviceCollectEditParam) {
        mlpAdviceCollectService.edit(mlpAdviceCollectEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除中长期规划管理-规划编制（意见收集）
     *
     * @author hujinachun
     * @date  2024/04/18 18:02
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除中长期规划管理-规划编制（意见收集）")
    @CommonLog("删除中长期规划管理-规划编制（意见收集）")
  //  @SaCheckPermission("/policy.info/mlpAdviceCollect/delete")
    @PostMapping("/policy.info/mlpAdviceCollect/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<MlpAdviceCollectIdParam> mlpAdviceCollectIdParamList) {
        mlpAdviceCollectService.delete(mlpAdviceCollectIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取中长期规划管理-规划编制（意见收集）详情
     *
     * @author hujinachun
     * @date  2024/04/18 18:02
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取中长期规划管理-规划编制（意见收集）详情")
   // @SaCheckPermission("/policy.info/mlpAdviceCollect/detail")
    @GetMapping("/policy.info/mlpAdviceCollect/detail")
    public CommonResult<MlpAdviceCollect> detail(@Valid MlpAdviceCollectIdParam mlpAdviceCollectIdParam) {
        return CommonResult.data(mlpAdviceCollectService.detail(mlpAdviceCollectIdParam));
    }


    /**
     * 获取中长期规划管理-查看意见
     *
     * @author hujinachun
     * @date  2024/04/18 18:02
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取中长期规划管理-规划编制（意见收集）详情")
    // @SaCheckPermission("/policy.info/mlpAdviceCollect/selectAdvice")
    @GetMapping("/policy.info/mlpAdviceCollect/selectAdvice")
    public CommonResult<List<MlpAdviceCollectVO>> selectAdvice(String id) {
        return CommonResult.data(mlpAdviceCollectService.selectAdvice(id));
    }


}
