/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpDraftAudit.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.policy.info.modular.mlpDraftModify.entity.MlpDraftModify;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.policy.info.modular.mlpDraftAudit.entity.MlpDraftAudit;
import com.unis.policy.info.modular.mlpDraftAudit.param.MlpDraftAuditAddParam;
import com.unis.policy.info.modular.mlpDraftAudit.param.MlpDraftAuditEditParam;
import com.unis.policy.info.modular.mlpDraftAudit.param.MlpDraftModifyIdParam;
import com.unis.policy.info.modular.mlpDraftAudit.param.MlpDraftAuditPageParam;
import com.unis.policy.info.modular.mlpDraftAudit.service.MlpDraftAuditService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;

/**
 * 中长期规划管理-专家评审控制器
 *
 * @author hjc
 * @date  2024/04/23 21:01
 */
@Api(tags = "中长期规划管理-专家评审控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class MlpDraftAuditController {

    @Resource
    private MlpDraftAuditService mlpDraftAuditService;

    /**
     * 获取中长期规划管理-专家评审分页
     *
     * @author hjc
     * @date  2024/04/23 21:01
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取中长期规划管理-专家评审分页")
   // @SaCheckPermission("/policy.info/mlpDraftAudit/page")
    @GetMapping("/policy.info/mlpDraftAudit/page")
    public CommonResult<Page<MlpDraftAudit>> page(MlpDraftAuditPageParam mlpDraftAuditPageParam) {
        return CommonResult.data(mlpDraftAuditService.page(mlpDraftAuditPageParam));
    }

    /**
     * 添加中长期规划管理-专家评审
     *
     * @author hjc
     * @date  2024/04/23 21:01
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加中长期规划管理-专家评审")
    @CommonLog("添加中长期规划管理-专家评审")
    //@SaCheckPermission("/policy.info/mlpDraftAudit/add")
    @PostMapping("/policy.info/mlpDraftAudit/add")
    public CommonResult<String> add(@RequestBody @Valid MlpDraftAuditAddParam mlpDraftAuditAddParam) {
        mlpDraftAuditService.add(mlpDraftAuditAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑中长期规划管理-专家评审
     *
     * @author hjc
     * @date  2024/04/23 21:01
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑中长期规划管理-专家评审")
    @CommonLog("编辑中长期规划管理-专家评审")
    //@SaCheckPermission("/policy.info/mlpDraftAudit/edit")
    @PostMapping("/policy.info/mlpDraftAudit/edit")
    public CommonResult<String> edit(@RequestBody @Valid MlpDraftAuditEditParam mlpDraftAuditEditParam) {
        mlpDraftAuditService.edit(mlpDraftAuditEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除中长期规划管理-专家评审
     *
     * @author hjc
     * @date  2024/04/23 21:01
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除中长期规划管理-专家评审")
    @CommonLog("删除中长期规划管理-专家评审")
    //@SaCheckPermission("/policy.info/mlpDraftAudit/delete")
    @PostMapping("/policy.info/mlpDraftAudit/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<MlpDraftModifyIdParam> mlpDraftAuditIdParamList) {
        mlpDraftAuditService.delete(mlpDraftAuditIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取中长期规划管理-专家评审详情
     *
     * @author hjc
     * @date  2024/04/23 21:01
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取中长期规划管理-专家评审详情")
    //@SaCheckPermission("/policy.info/mlpDraftAudit/detail")
    @GetMapping("/policy.info/mlpDraftAudit/detail")
    public CommonResult<MlpDraftAudit> detail(@Valid MlpDraftModifyIdParam mlpDraftAuditIdParam) {
        return CommonResult.data(mlpDraftAuditService.detail(mlpDraftAuditIdParam));
    }


    /**
     * 获取中长期规划管理-规划id获取详情
     *
     * @author hjc
     * @date  2024/04/23 21:01
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取中长期规划管理-规划id获取详情")
    //@SaCheckPermission("/policy.info/mlpDraftAudit/getDraftModify")
    @GetMapping("/policy.info/mlpDraftAudit/getDraftModify")
    public CommonResult<MlpDraftModify> getDraftModify(@Valid MlpDraftModifyIdParam mlpDraftModifyIdParam) {
        return CommonResult.data(mlpDraftAuditService.getDraftModify(mlpDraftModifyIdParam));
    }

}
