/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpDraftAuditExpert.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.policy.info.modular.mlpDraftAuditExpert.entity.MlpDraftAuditExpert;
import com.unis.policy.info.modular.mlpDraftAuditExpert.mapper.MlpDraftAuditExpertMapper;
import com.unis.policy.info.modular.mlpDraftAuditExpert.param.MlpDraftAuditExpertAddParam;
import com.unis.policy.info.modular.mlpDraftAuditExpert.param.MlpDraftAuditExpertEditParam;
import com.unis.policy.info.modular.mlpDraftAuditExpert.param.MlpDraftAuditExpertIdParam;
import com.unis.policy.info.modular.mlpDraftAuditExpert.param.MlpDraftAuditExpertPageParam;
import com.unis.policy.info.modular.mlpDraftAuditExpert.service.MlpDraftAuditExpertService;

import java.util.List;

/**
 * 中长期规划管理-专家评审-专家Service接口实现类
 *
 * @author hjc
 * @date  2024/04/24 10:58
 **/
@Service
public class MlpDraftAuditExpertServiceImpl extends ServiceImpl<MlpDraftAuditExpertMapper, MlpDraftAuditExpert> implements MlpDraftAuditExpertService {

    @Override
    public Page<MlpDraftAuditExpert> page(MlpDraftAuditExpertPageParam mlpDraftAuditExpertPageParam) {
        QueryWrapper<MlpDraftAuditExpert> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isAllNotEmpty(mlpDraftAuditExpertPageParam.getSortField(), mlpDraftAuditExpertPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(mlpDraftAuditExpertPageParam.getSortOrder());
            queryWrapper.orderBy(true, mlpDraftAuditExpertPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(mlpDraftAuditExpertPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(MlpDraftAuditExpert::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(MlpDraftAuditExpertAddParam mlpDraftAuditExpertAddParam) {
        MlpDraftAuditExpert mlpDraftAuditExpert = BeanUtil.toBean(mlpDraftAuditExpertAddParam, MlpDraftAuditExpert.class);
        this.save(mlpDraftAuditExpert);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(MlpDraftAuditExpertEditParam mlpDraftAuditExpertEditParam) {
        MlpDraftAuditExpert mlpDraftAuditExpert = this.queryEntity(mlpDraftAuditExpertEditParam.getId());
        BeanUtil.copyProperties(mlpDraftAuditExpertEditParam, mlpDraftAuditExpert);
        this.updateById(mlpDraftAuditExpert);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<MlpDraftAuditExpertIdParam> mlpDraftAuditExpertIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(mlpDraftAuditExpertIdParamList, MlpDraftAuditExpertIdParam::getId));
    }

    @Override
    public MlpDraftAuditExpert detail(MlpDraftAuditExpertIdParam mlpDraftAuditExpertIdParam) {
        return this.queryEntity(mlpDraftAuditExpertIdParam.getId());
    }

    @Override
    public MlpDraftAuditExpert queryEntity(String id) {
        MlpDraftAuditExpert mlpDraftAuditExpert = this.getById(id);
        if(ObjectUtil.isEmpty(mlpDraftAuditExpert)) {
            throw new CommonException("中长期规划管理-专家评审-专家不存在，id值为：{}", id);
        }
        return mlpDraftAuditExpert;
    }
}
