/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpFirstDraft.service.impl;

import cn.dev33.satoken.stp.StpUtil;
import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.unis.auth.core.pojo.SaBaseLoginUser;
import com.unis.auth.core.util.StpLoginUserUtil;
import com.unis.policy.info.modular.mlpFirstDraft.param.*;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import com.unis.common.enums.CommonSortOrderEnum;
import com.unis.common.exception.CommonException;
import com.unis.common.page.CommonPageRequest;
import com.unis.policy.info.modular.mlpFirstDraft.entity.MlpFirstDraft;
import com.unis.policy.info.modular.mlpFirstDraft.mapper.MlpFirstDraftMapper;
import com.unis.policy.info.modular.mlpFirstDraft.service.MlpFirstDraftService;
import org.springframework.util.StringUtils;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 中长期规划管理-规划初稿(规划拟稿)Service接口实现类
 *
 * @author QSHan
 * @date  2024/04/18 16:52
 **/
@Service
public class MlpFirstDraftServiceImpl extends ServiceImpl<MlpFirstDraftMapper, MlpFirstDraft> implements MlpFirstDraftService {
    @Resource
    private MlpFirstDraftMapper firstDraftMapper;

    @Override
    public Page<MlpFirstDraft> page(MlpFirstDraftPageParam mlpFirstDraftPageParam, MlpFirstDraftQueryParam param) {
        QueryWrapper<MlpFirstDraft> queryWrapper = new QueryWrapper<>();
        // 规划名称
        if (StringUtils.hasText(param.getPlanName()))
            queryWrapper.like("plan_name" ,param.getPlanName());
        // 完成日期
        if (!ObjectUtil.isEmpty(param.getDeadline()))
            queryWrapper.eq("deadline", param.getDeadline());
        // 校验数据范围
        /*List<String> loginUserDataScope = StpLoginUserUtil.getLoginUserDataScope();
        if(ObjectUtil.isNotEmpty(loginUserDataScope)) {
            //数据范围不为空，则查询这些机构内的
            queryWrapper.lambda().in(MlpFirstDraft::getSysOrgId, loginUserDataScope);
        } else {
            //否则只查询自己的
            SaBaseLoginUser loginUser = StpLoginUserUtil.getLoginUser();
            queryWrapper.lambda().eq(MlpFirstDraft::getCreateUser, loginUser.getId());
        }*/
        // 排序
        if(ObjectUtil.isAllNotEmpty(mlpFirstDraftPageParam.getSortField(), mlpFirstDraftPageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(mlpFirstDraftPageParam.getSortOrder());
            queryWrapper.orderBy(true, mlpFirstDraftPageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(mlpFirstDraftPageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(MlpFirstDraft::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(MlpFirstDraftAddParam mlpFirstDraftAddParam) {
        MlpFirstDraft mlpFirstDraft = BeanUtil.toBean(mlpFirstDraftAddParam, MlpFirstDraft.class);
        this.save(mlpFirstDraft);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(MlpFirstDraftEditParam mlpFirstDraftEditParam) {
        MlpFirstDraft mlpFirstDraft = this.queryEntity(mlpFirstDraftEditParam.getId());
        BeanUtil.copyProperties(mlpFirstDraftEditParam, mlpFirstDraft);
        this.updateById(mlpFirstDraft);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<MlpFirstDraftIdParam> mlpFirstDraftIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(mlpFirstDraftIdParamList, MlpFirstDraftIdParam::getId));
    }

    @Override
    public MlpFirstDraft detail(MlpFirstDraftIdParam mlpFirstDraftIdParam) {
        return this.queryEntity(mlpFirstDraftIdParam.getId());
    }

    @Override
    public MlpFirstDraft queryEntity(String id) {
        MlpFirstDraft mlpFirstDraft = this.getById(id);
        if(ObjectUtil.isEmpty(mlpFirstDraft)) {
            throw new CommonException("中长期规划管理-规划初稿(规划拟稿)不存在，id值为：{}", id);
        }
        return mlpFirstDraft;
    }

    @Override
    public Map<String, Object> getPlanName() {
        Map<String, Object> resultMap = new HashMap<>();
        // 获取当前日期,查询完成日期内的数据
        List<Map<String, String>> mapNow = firstDraftMapper.getPlanName(LocalDate.now().toString());
        resultMap.put("mapNow", mapNow);
        List<Map<String, String>> mapAll = firstDraftMapper.getPlanName("");
        resultMap.put("mapAll", mapAll);
        return resultMap;
    }

}
