/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.unis.policy.info.modular.mlpFirstDraftCollect.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import com.unis.policy.info.modular.mlpFirstDraftCollect.param.*;
import com.unis.policy.info.modular.mlpFirstDraftCollectFeedback.param.MlpFirstDraftCollectFeedbackAddParam;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import com.unis.common.annotation.CommonLog;
import com.unis.common.pojo.CommonResult;
import com.unis.common.pojo.CommonValidList;
import com.unis.policy.info.modular.mlpFirstDraftCollect.entity.MlpFirstDraftCollect;
import com.unis.policy.info.modular.mlpFirstDraftCollect.service.MlpFirstDraftCollectService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 中长期规划管理-初稿意见征集控制器
 *
 * @author QSHan
 * @date  2024/04/18 20:02
 */
@Api(tags = "中长期规划管理-初稿意见征集控制器")
@ApiSupport(author = "UNIS_TEAM", order = 1)
@RestController
@Validated
public class MlpFirstDraftCollectController {

    @Resource
    private MlpFirstDraftCollectService mlpFirstDraftCollectService;

    /**
     * 获取中长期规划管理-初稿意见征集分页
     *
     * @author QSHan
     * @date  2024/04/18 20:02
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("分页-初稿意见征集")
//    @SaCheckPermission("/policy.info/mlpFirstDraftCollect/page")
    @GetMapping("/policy.info/mlpFirstDraftCollect/page")
    public CommonResult<IPage<MlpFirstDraftCollect>> page(MlpFirstDraftCollectPageParam mlpFirstDraftCollectPageParam, MlpFirstDraftCollectQueryParam param) {
        return CommonResult.data(mlpFirstDraftCollectService.page(mlpFirstDraftCollectPageParam, param));
    }

    /**
     * 添加中长期规划管理-初稿意见征集
     *
     * @author QSHan
     * @date  2024/04/18 20:02
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加-初稿意见征集")
    @CommonLog("添加-初稿意见征集")
//    @SaCheckPermission("/policy.info/mlpFirstDraftCollect/add")
    @PostMapping("/policy.info/mlpFirstDraftCollect/add")
    public CommonResult<String> add(@RequestBody @Valid MlpFirstDraftCollectAddParam mlpFirstDraftCollectAddParam) {
        mlpFirstDraftCollectService.add(mlpFirstDraftCollectAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑中长期规划管理-初稿意见征集
     *
     * @author QSHan
     * @date  2024/04/18 20:02
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑-初稿意见征集")
    @CommonLog("编辑-初稿意见征集")
//    @SaCheckPermission("/policy.info/mlpFirstDraftCollect/edit")
    @PostMapping("/policy.info/mlpFirstDraftCollect/edit")
    public CommonResult<String> edit(@RequestBody @Valid MlpFirstDraftCollectEditParam mlpFirstDraftCollectEditParam) {
        mlpFirstDraftCollectService.edit(mlpFirstDraftCollectEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除中长期规划管理-初稿意见征集
     *
     * @author QSHan
     * @date  2024/04/18 20:02
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除-初稿意见征集")
    @CommonLog("删除-初稿意见征集")
//    @SaCheckPermission("/policy.info/mlpFirstDraftCollect/delete")
    @PostMapping("/policy.info/mlpFirstDraftCollect/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<MlpFirstDraftCollectIdParam> mlpFirstDraftCollectIdParamList) {
        mlpFirstDraftCollectService.delete(mlpFirstDraftCollectIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取中长期规划管理-初稿意见征集详情
     *
     * @author QSHan
     * @date  2024/04/18 20:02
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取-初稿意见征集详情")
//    @SaCheckPermission("/policy.info/mlpFirstDraftCollect/detail")
    @GetMapping("/policy.info/mlpFirstDraftCollect/detail")
    public CommonResult<MlpFirstDraftCollect> detail(@Valid MlpFirstDraftCollectIdParam mlpFirstDraftCollectIdParam) {
        return CommonResult.data(mlpFirstDraftCollectService.detail(mlpFirstDraftCollectIdParam));
    }

    @ApiOperationSupport(order = 6)
    @ApiOperation("初稿意见征集-查看意见")
    @GetMapping("/policy.info/mlpFirstDraftCollect/checkList")
    public CommonResult<List<MlpFirstDraftCollectFeedbackAddParam>> checkList(String id) {
        return CommonResult.data(mlpFirstDraftCollectService.checkList(id));
    }

}
